Technical Documentation
=======================

This is the technical documentation for the **denofo** project. 
It is intended for developers and contributors to the project.

.. toctree::
   :maxdepth: 2
   :caption: modules and tools:

   denofo
   questionnaire
   converter
   comparator
   utils
